Index: /trunk/src/VBox/VMM/SSM.cpp
===================================================================
--- /trunk/src/VBox/VMM/SSM.cpp	(revision 23595)
+++ /trunk/src/VBox/VMM/SSM.cpp	(revision 23596)
@@ -4125,5 +4125,5 @@
  * @param   enmAfter            What to do afterwards.
  * @param   pfnProgress         The progress callback.
  * @param   pvUser              The progress callback user argument.
  * @param   ppSSM               Where to return the pointer to the saved state
  *                              handle upon successful return.  Free it using
@@ -4131,5 +4131,5 @@
  */
 static int ssmR3SaveDoCreateFile(PVM pVM, const char *pszFilename, PCSSMSTRMOPS pStreamOps, void *pvStreamOpsUser,
-                                 SSMAFTER enmAfter, PFNVMPROGRESS pfnProgress, void *pvUser, PSSMHANDLE *ppSSM)
+                                 SSMAFTER enmAfter, PFNVMPROGRESS pfnProgress, void *pvProgressUser, PSSMHANDLE *ppSSM)
 {
     PSSMHANDLE pSSM = (PSSMHANDLE)RTMemAllocZ(sizeof(*pSSM));
@@ -4146,5 +4146,5 @@
     pSSM->fLiveSave             = false;
     pSSM->pfnProgress           = pfnProgress;
-    pSSM->pvUser                = pvUser;
+    pSSM->pvUser                = pvProgressUser;
     pSSM->uPercent              = 0;
     pSSM->offEstProgress        = 0;
@@ -4621,9 +4621,13 @@
  *
  * @param   pVM             The VM handle.
- * @param   pszFilename     Name of the file to save the state in.  This string
+ * @param   pszFilename     Name of the file to save the state in. This string
  *                          must remain valid until SSMR3LiveDone is called.
+ *                          Must be NULL if pStreamOps is used.
+ * @param   pStreamOps      The stream method table. NULL if pszFilename is
+ *                          used.
+ * @param   pvStreamOpsUser The user argument to the stream methods.
  * @param   enmAfter        What is planned after a successful save operation.
  * @param   pfnProgress     Progress callback. Optional.
  * @param   pvUser          User argument for the progress callback.
  *
  * @thread  EMT0
@@ -7048,9 +7052,9 @@
  * @param   pStreamOps      The stream method table. NULL if pszFilename is
  *                          used.
- * @param   pStreamOpsUser  The user argument for the stream methods.
+ * @param   pvStreamOpsUser The user argument for the stream methods.
  * @param   enmAfter        What is planned after a successful load operation.
  *                          Only acceptable values are SSMAFTER_RESUME and SSMAFTER_DEBUG_IT.
  * @param   pfnProgress     Progress callback. Optional.
  * @param   pvUser          User argument for the progress callback.
  *
  * @thread  EMT
@@ -4125,5 +4125,5 @@
  * @param   enmAfter            What to do afterwards.
  * @param   pfnProgress         The progress callback.
- * @param   pvUser              The progress callback user argument.
+ * @param   pvProgressUser      The progress callback user argument.
  * @param   ppSSM               Where to return the pointer to the saved state
  *                              handle upon successful return.  Free it using
@@ -4621,9 +4621,13 @@
  * @param   enmAfter        What is planned after a successful save operation.
  * @param   pfnProgress     Progress callback. Optional.
- * @param   pvUser          User argument for the progress callback.
+ * @param   pvProgressUser  User argument for the progress callback.
  *
  * @thread  EMT0
@@ -7048,9 +7052,9 @@
  *                          Only acceptable values are SSMAFTER_RESUME and SSMAFTER_DEBUG_IT.
  * @param   pfnProgress     Progress callback. Optional.
- * @param   pvUser          User argument for the progress callback.
+ * @param   pvProgressUser  User argument for the progress callback.
  *
  * @thread  EMT
